@@ -9,9 +9,9 @@
 
 #include "customfieldeditorwidgettest.h"
 #include "../customfieldeditorwidget.h"
-#include <KLineEdit>
 #include <QComboBox>
 #include <QLabel>
+#include <QLineEdit>
 #include <QPushButton>
 #include <QTest>
 
@@ -25,10 +25,9 @@ CustomFieldEditorWidgetTest::~CustomFieldEditorWidgetTest() = default;
 void CustomFieldEditorWidgetTest::shouldHaveDefaultValue()
 {
     Akonadi::CustomFieldEditorWidget w;
-    auto fieldname = w.findChild<KLineEdit *>(QStringLiteral("fieldname"));
+    auto fieldname = w.findChild<QLineEdit *>(QStringLiteral("fieldname"));
     QVERIFY(fieldname);
     QVERIFY(fieldname->text().isEmpty());
-    QVERIFY(fieldname->trapReturnKey());
 
     auto label = w.findChild<QLabel *>(QStringLiteral("labeltitle"));
     QVERIFY(label);
