@@ -8,12 +8,12 @@
 
 #pragma once
 
-#include <KLineEdit>
 #include <QIcon>
+#include <QLineEdit>
 class QAction;
 namespace Akonadi
 {
-class PreferredLineEditWidget : public KLineEdit
+class PreferredLineEditWidget : public QLineEdit
 {
     Q_OBJECT
 public:
@@ -31,8 +31,8 @@ private:
     void slotPreferredStatusChanged();
     void updatePreferredIcon();
     bool mPreferred = false;
-    QIcon mIconEnabled;
-    QIcon mIconDisabled;
+    const QIcon mIconEnabled;
+    const QIcon mIconDisabled;
     QAction *mPreferredAction = nullptr;
 };
 }
